==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZlecenieSoczewka.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.enums.RodzajSoczewki;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class ZlecenieSoczewka extends GenericDPSObject {
    /**
     * ZLECENIE_SOCZEWKA.ZLECENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zlecenieId;

    /**
     * ZLECENIE_SOCZEWKA.RODZAJ
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajSoczewki rodzaj;

    /**
     * ZLECENIE_SOCZEWKA.OL_SFERA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal olSfera;

    /**
     * ZLECENIE_SOCZEWKA.OL_CYLINDER
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal olCylinder;

    /**
     * ZLECENIE_SOCZEWKA.OL_OS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal olOs;

    /**
     * ZLECENIE_SOCZEWKA.OL_PRYZMA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal olPryzma;

    /**
     * ZLECENIE_SOCZEWKA.OP_SFERA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal opSfera;

    /**
     * ZLECENIE_SOCZEWKA.OP_CYLINDER
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal opCylinder;

    /**
     * ZLECENIE_SOCZEWKA.OP_OS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal opOs;

    /**
     * ZLECENIE_SOCZEWKA.OP_PRYZMA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal opPryzma;

    /**
     * ZLECENIE_SOCZEWKA.ODL_ZRENIC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer odlZrenic;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZLECENIE_SOCZEWKA.ZLECENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZlecenieId() {
        return zlecenieId;
    }

    /**
     * ZLECENIE_SOCZEWKA.ZLECENIE_ID
     *
     * @param zlecenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZlecenieId(Long zlecenieId) {
        this.zlecenieId = zlecenieId;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.RODZAJ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajSoczewki getRodzaj() {
        return rodzaj;
    }

    /**
     * ZLECENIE_SOCZEWKA.RODZAJ
     *
     * @param rodzaj
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzaj(RodzajSoczewki rodzaj) {
        this.rodzaj = rodzaj;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OL_SFERA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getOlSfera() {
        return olSfera;
    }

    /**
     * ZLECENIE_SOCZEWKA.OL_SFERA
     *
     * @param olSfera
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOlSfera(BigDecimal olSfera) {
        this.olSfera = olSfera;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OL_CYLINDER
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getOlCylinder() {
        return olCylinder;
    }

    /**
     * ZLECENIE_SOCZEWKA.OL_CYLINDER
     *
     * @param olCylinder
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOlCylinder(BigDecimal olCylinder) {
        this.olCylinder = olCylinder;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OL_OS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getOlOs() {
        return olOs;
    }

    /**
     * ZLECENIE_SOCZEWKA.OL_OS
     *
     * @param olOs
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOlOs(BigDecimal olOs) {
        this.olOs = olOs;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OL_PRYZMA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getOlPryzma() {
        return olPryzma;
    }

    /**
     * ZLECENIE_SOCZEWKA.OL_PRYZMA
     *
     * @param olPryzma
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOlPryzma(BigDecimal olPryzma) {
        this.olPryzma = olPryzma;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OP_SFERA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getOpSfera() {
        return opSfera;
    }

    /**
     * ZLECENIE_SOCZEWKA.OP_SFERA
     *
     * @param opSfera
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpSfera(BigDecimal opSfera) {
        this.opSfera = opSfera;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OP_CYLINDER
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getOpCylinder() {
        return opCylinder;
    }

    /**
     * ZLECENIE_SOCZEWKA.OP_CYLINDER
     *
     * @param opCylinder
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpCylinder(BigDecimal opCylinder) {
        this.opCylinder = opCylinder;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OP_OS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getOpOs() {
        return opOs;
    }

    /**
     * ZLECENIE_SOCZEWKA.OP_OS
     *
     * @param opOs
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpOs(BigDecimal opOs) {
        this.opOs = opOs;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OP_PRYZMA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getOpPryzma() {
        return opPryzma;
    }

    /**
     * ZLECENIE_SOCZEWKA.OP_PRYZMA
     *
     * @param opPryzma
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpPryzma(BigDecimal opPryzma) {
        this.opPryzma = opPryzma;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.ODL_ZRENIC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getOdlZrenic() {
        return odlZrenic;
    }

    /**
     * ZLECENIE_SOCZEWKA.ODL_ZRENIC
     *
     * @param odlZrenic
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOdlZrenic(Integer odlZrenic) {
        this.odlZrenic = odlZrenic;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZlecenieSoczewka other = (ZlecenieSoczewka) that;
        return (this.getZlecenieId() == null ? other.getZlecenieId() == null : this.getZlecenieId().equals(other.getZlecenieId()))
            && (this.getRodzaj() == null ? other.getRodzaj() == null : this.getRodzaj().equals(other.getRodzaj()))
            && (this.getOlSfera() == null ? other.getOlSfera() == null : this.getOlSfera().equals(other.getOlSfera()))
            && (this.getOlCylinder() == null ? other.getOlCylinder() == null : this.getOlCylinder().equals(other.getOlCylinder()))
            && (this.getOlOs() == null ? other.getOlOs() == null : this.getOlOs().equals(other.getOlOs()))
            && (this.getOlPryzma() == null ? other.getOlPryzma() == null : this.getOlPryzma().equals(other.getOlPryzma()))
            && (this.getOpSfera() == null ? other.getOpSfera() == null : this.getOpSfera().equals(other.getOpSfera()))
            && (this.getOpCylinder() == null ? other.getOpCylinder() == null : this.getOpCylinder().equals(other.getOpCylinder()))
            && (this.getOpOs() == null ? other.getOpOs() == null : this.getOpOs().equals(other.getOpOs()))
            && (this.getOpPryzma() == null ? other.getOpPryzma() == null : this.getOpPryzma().equals(other.getOpPryzma()))
            && (this.getOdlZrenic() == null ? other.getOdlZrenic() == null : this.getOdlZrenic().equals(other.getOdlZrenic()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getZlecenieId() == null) ? 0 : getZlecenieId().hashCode());
        result = prime * result + ((getRodzaj() == null) ? 0 : getRodzaj().hashCode());
        result = prime * result + ((getOlSfera() == null) ? 0 : getOlSfera().hashCode());
        result = prime * result + ((getOlCylinder() == null) ? 0 : getOlCylinder().hashCode());
        result = prime * result + ((getOlOs() == null) ? 0 : getOlOs().hashCode());
        result = prime * result + ((getOlPryzma() == null) ? 0 : getOlPryzma().hashCode());
        result = prime * result + ((getOpSfera() == null) ? 0 : getOpSfera().hashCode());
        result = prime * result + ((getOpCylinder() == null) ? 0 : getOpCylinder().hashCode());
        result = prime * result + ((getOpOs() == null) ? 0 : getOpOs().hashCode());
        result = prime * result + ((getOpPryzma() == null) ? 0 : getOpPryzma().hashCode());
        result = prime * result + ((getOdlZrenic() == null) ? 0 : getOdlZrenic().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", zlecenieId=").append(zlecenieId);
        sb.append(", rodzaj=").append(rodzaj);
        sb.append(", olSfera=").append(olSfera);
        sb.append(", olCylinder=").append(olCylinder);
        sb.append(", olOs=").append(olOs);
        sb.append(", olPryzma=").append(olPryzma);
        sb.append(", opSfera=").append(opSfera);
        sb.append(", opCylinder=").append(opCylinder);
        sb.append(", opOs=").append(opOs);
        sb.append(", opPryzma=").append(opPryzma);
        sb.append(", odlZrenic=").append(odlZrenic);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZlecenieSoczewka.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.enums.RodzajSoczewki;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class ZlecenieSoczewka extends GenericDPSObject {
    /**
     * ZLECENIE_SOCZEWKA.ZLECENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zlecenieId;

    /**
     * ZLECENIE_SOCZEWKA.RODZAJ
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajSoczewki rodzaj;

    /**
     * ZLECENIE_SOCZEWKA.OL_SFERA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal olSfera;

    /**
     * ZLECENIE_SOCZEWKA.OL_CYLINDER
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal olCylinder;

    /**
     * ZLECENIE_SOCZEWKA.OL_OS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal olOs;

    /**
     * ZLECENIE_SOCZEWKA.OL_PRYZMA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal olPryzma;

    /**
     * ZLECENIE_SOCZEWKA.OP_SFERA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal opSfera;

    /**
     * ZLECENIE_SOCZEWKA.OP_CYLINDER
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal opCylinder;

    /**
     * ZLECENIE_SOCZEWKA.OP_OS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal opOs;

    /**
     * ZLECENIE_SOCZEWKA.OP_PRYZMA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal opPryzma;

    /**
     * ZLECENIE_SOCZEWKA.ODL_ZRENIC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer odlZrenic;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZLECENIE_SOCZEWKA.ZLECENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZlecenieId() {
        return zlecenieId;
    }

    /**
     * ZLECENIE_SOCZEWKA.ZLECENIE_ID
     *
     * @param zlecenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZlecenieId(Long zlecenieId) {
        this.zlecenieId = zlecenieId;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.RODZAJ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajSoczewki getRodzaj() {
        return rodzaj;
    }

    /**
     * ZLECENIE_SOCZEWKA.RODZAJ
     *
     * @param rodzaj
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzaj(RodzajSoczewki rodzaj) {
        this.rodzaj = rodzaj;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OL_SFERA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getOlSfera() {
        return olSfera;
    }

    /**
     * ZLECENIE_SOCZEWKA.OL_SFERA
     *
     * @param olSfera
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOlSfera(BigDecimal olSfera) {
        this.olSfera = olSfera;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OL_CYLINDER
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getOlCylinder() {
        return olCylinder;
    }

    /**
     * ZLECENIE_SOCZEWKA.OL_CYLINDER
     *
     * @param olCylinder
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOlCylinder(BigDecimal olCylinder) {
        this.olCylinder = olCylinder;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OL_OS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getOlOs() {
        return olOs;
    }

    /**
     * ZLECENIE_SOCZEWKA.OL_OS
     *
     * @param olOs
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOlOs(BigDecimal olOs) {
        this.olOs = olOs;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OL_PRYZMA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getOlPryzma() {
        return olPryzma;
    }

    /**
     * ZLECENIE_SOCZEWKA.OL_PRYZMA
     *
     * @param olPryzma
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOlPryzma(BigDecimal olPryzma) {
        this.olPryzma = olPryzma;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OP_SFERA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getOpSfera() {
        return opSfera;
    }

    /**
     * ZLECENIE_SOCZEWKA.OP_SFERA
     *
     * @param opSfera
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpSfera(BigDecimal opSfera) {
        this.opSfera = opSfera;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OP_CYLINDER
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getOpCylinder() {
        return opCylinder;
    }

    /**
     * ZLECENIE_SOCZEWKA.OP_CYLINDER
     *
     * @param opCylinder
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpCylinder(BigDecimal opCylinder) {
        this.opCylinder = opCylinder;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OP_OS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getOpOs() {
        return opOs;
    }

    /**
     * ZLECENIE_SOCZEWKA.OP_OS
     *
     * @param opOs
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpOs(BigDecimal opOs) {
        this.opOs = opOs;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.OP_PRYZMA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getOpPryzma() {
        return opPryzma;
    }

    /**
     * ZLECENIE_SOCZEWKA.OP_PRYZMA
     *
     * @param opPryzma
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpPryzma(BigDecimal opPryzma) {
        this.opPryzma = opPryzma;
    }

    /**
     * @return ZLECENIE_SOCZEWKA.ODL_ZRENIC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getOdlZrenic() {
        return odlZrenic;
    }

    /**
     * ZLECENIE_SOCZEWKA.ODL_ZRENIC
     *
     * @param odlZrenic
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOdlZrenic(Integer odlZrenic) {
        this.odlZrenic = odlZrenic;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZlecenieSoczewka other = (ZlecenieSoczewka) that;
        return (this.getZlecenieId() == null ? other.getZlecenieId() == null : this.getZlecenieId().equals(other.getZlecenieId()))
            && (this.getRodzaj() == null ? other.getRodzaj() == null : this.getRodzaj().equals(other.getRodzaj()))
            && (this.getOlSfera() == null ? other.getOlSfera() == null : this.getOlSfera().equals(other.getOlSfera()))
            && (this.getOlCylinder() == null ? other.getOlCylinder() == null : this.getOlCylinder().equals(other.getOlCylinder()))
            && (this.getOlOs() == null ? other.getOlOs() == null : this.getOlOs().equals(other.getOlOs()))
            && (this.getOlPryzma() == null ? other.getOlPryzma() == null : this.getOlPryzma().equals(other.getOlPryzma()))
            && (this.getOpSfera() == null ? other.getOpSfera() == null : this.getOpSfera().equals(other.getOpSfera()))
            && (this.getOpCylinder() == null ? other.getOpCylinder() == null : this.getOpCylinder().equals(other.getOpCylinder()))
            && (this.getOpOs() == null ? other.getOpOs() == null : this.getOpOs().equals(other.getOpOs()))
            && (this.getOpPryzma() == null ? other.getOpPryzma() == null : this.getOpPryzma().equals(other.getOpPryzma()))
            && (this.getOdlZrenic() == null ? other.getOdlZrenic() == null : this.getOdlZrenic().equals(other.getOdlZrenic()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getZlecenieId() == null) ? 0 : getZlecenieId().hashCode());
        result = prime * result + ((getRodzaj() == null) ? 0 : getRodzaj().hashCode());
        result = prime * result + ((getOlSfera() == null) ? 0 : getOlSfera().hashCode());
        result = prime * result + ((getOlCylinder() == null) ? 0 : getOlCylinder().hashCode());
        result = prime * result + ((getOlOs() == null) ? 0 : getOlOs().hashCode());
        result = prime * result + ((getOlPryzma() == null) ? 0 : getOlPryzma().hashCode());
        result = prime * result + ((getOpSfera() == null) ? 0 : getOpSfera().hashCode());
        result = prime * result + ((getOpCylinder() == null) ? 0 : getOpCylinder().hashCode());
        result = prime * result + ((getOpOs() == null) ? 0 : getOpOs().hashCode());
        result = prime * result + ((getOpPryzma() == null) ? 0 : getOpPryzma().hashCode());
        result = prime * result + ((getOdlZrenic() == null) ? 0 : getOdlZrenic().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", zlecenieId=").append(zlecenieId);
        sb.append(", rodzaj=").append(rodzaj);
        sb.append(", olSfera=").append(olSfera);
        sb.append(", olCylinder=").append(olCylinder);
        sb.append(", olOs=").append(olOs);
        sb.append(", olPryzma=").append(olPryzma);
        sb.append(", opSfera=").append(opSfera);
        sb.append(", opCylinder=").append(opCylinder);
        sb.append(", opOs=").append(opOs);
        sb.append(", opPryzma=").append(opPryzma);
        sb.append(", odlZrenic=").append(odlZrenic);
        sb.append("]");
        return sb.toString();
    }
}
